"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServiceCollectionFactory = void 0;
const object_1 = require("../services/object");
const storage_1 = require("../services/storage");
const agileServiceFactory_1 = require("./agileServiceFactory");
const playbookServiceFactory_1 = require("./playbookServiceFactory");
const repoServiceFactory_1 = require("./repoServiceFactory");
/**
 * Factory for collections of services
 */
class ServiceCollectionFactory {
    /**
     * Create collection of shared services
     *
     * @returns {ServiceCollection} Service Collection
     */
    static create() {
        const localFileStorageService = new storage_1.FileStorageService(process.cwd());
        const parameterService = new object_1.ObjectService(localFileStorageService);
        const backlogItemTemplateService = new object_1.ObjectService(localFileStorageService);
        const contentService = new object_1.ObjectService(localFileStorageService);
        return {
            getAgileService: agileServiceFactory_1.AgileServiceFactory.get,
            getRepoService: repoServiceFactory_1.RepoServiceFactory.get,
            getPlaybookService: (options) => playbookServiceFactory_1.PlaybookServiceFactory.get(options, contentService),
            backlogItemTemplateService,
            parameterService,
            contentService,
        };
    }
}
exports.ServiceCollectionFactory = ServiceCollectionFactory;
